@@ -7,7 +7,8 @@ from ._base import IDdEnergyBaseModel
 from .material import EnergyMaterial, EnergyMaterialNoMass, EnergyMaterialVegetation, \
     EnergyWindowMaterialGas, EnergyWindowMaterialGasCustom, \
     EnergyWindowMaterialGasMixture, EnergyWindowMaterialSimpleGlazSys, \
-    EnergyWindowMaterialGlazing, EnergyWindowMaterialShade, EnergyWindowMaterialBlind
+    EnergyWindowMaterialGlazing, EnergyWindowFrame, \
+    EnergyWindowMaterialShade, EnergyWindowMaterialBlind
 from .schedule import ScheduleRuleset, ScheduleFixedInterval
 
 
@@ -57,6 +58,14 @@ class WindowConstructionAbridged(IDdEnergyBaseModel):
         max_items=8
     )
 
+    frame: str = Field(
+        None,
+        min_length=1,
+        max_length=100,
+        description='An optional identifier for a frame material that '
+        'surrounds the window construction.'
+    )
+
 
 class WindowConstruction(WindowConstructionAbridged):
     """Construction for window objects (Aperture, Door)."""
@@ -80,6 +89,12 @@ class WindowConstruction(WindowConstructionAbridged):
         max_items=8
     )
 
+    frame: EnergyWindowFrame = Field(
+        None,
+        description='An optional window frame material for the frame that '
+        'surrounds the window construction.'
+    )
+
 
 class ShadeLocation(str, Enum):
     """Choices for where a shade material is located in a window assembly."""
@@ -131,7 +146,7 @@ class WindowConstructionShadeAbridged(IDdEnergyBaseModel):
         description='Text to indicate where in the window assembly the shade_material '
         'is located.  Note that the WindowConstruction must have at least one gas '
         'gap to use the "Between" option. Also note that, for a WindowConstruction '
-        'with more than one gas gap, the "Between" option defalts to using the '
+        'with more than one gas gap, the "Between" option defaults to using the '
         'inner gap as this is the only option that EnergyPlus supports.'
     )
 
@@ -209,7 +224,7 @@ class WindowConstructionDynamicAbridged(IDdEnergyBaseModel):
         max_length=100,
         description='An identifier for a control schedule that dictates which '
         'constructions are active at given times throughout the simulation. The values '
-        'of the schedule should be intergers and range from 0 to one less then the '
+        'of the schedule should be integers and range from 0 to one less then the '
         'number of constructions. Zero indicates that the first construction is active, '
         'one indicates that the second on is active, etc. The schedule type limits '
         'of this schedule should be "Control Level." If building custom schedule '
@@ -235,7 +250,7 @@ class WindowConstructionDynamic(IDdEnergyBaseModel):
         ...,
         description='A control schedule that dictates which constructions '
         'are active at given times throughout the simulation. The values of the '
-        'schedule should be intergers and range from 0 to one less then the number '
+        'schedule should be integers and range from 0 to one less then the number '
         'of constructions. Zero indicates that the first construction is active, '
         'one indicates that the second on is active, etc. The schedule type limits '
         'of this schedule should be "Control Level." If building custom schedule '
@@ -287,7 +302,7 @@ class AirBoundaryConstructionAbridged(IDdEnergyBaseModel):
         'typical of what would be induced by a HVAC system.'
     )
 
-    air_mixing_schedule: str = Field( 
+    air_mixing_schedule: str = Field(
         default=None,
         min_length=1,
         max_length=100,
