@@ -10,9 +10,10 @@ from .construction import OpaqueConstructionAbridged, WindowConstructionAbridged
     WindowConstruction, AirBoundaryConstruction, WindowConstructionShadeAbridged, \
     WindowConstructionShade, WindowConstructionDynamicAbridged, WindowConstructionDynamic
 from .material import EnergyMaterial, EnergyMaterialNoMass, EnergyMaterialVegetation, \
+    EnergyWindowMaterialSimpleGlazSys, EnergyWindowMaterialGlazing, \
     EnergyWindowMaterialGas, EnergyWindowMaterialGasCustom, \
-    EnergyWindowMaterialGasMixture, EnergyWindowMaterialSimpleGlazSys, \
-    EnergyWindowMaterialBlind, EnergyWindowMaterialGlazing, EnergyWindowMaterialShade
+    EnergyWindowMaterialGasMixture, EnergyWindowFrame, \
+    EnergyWindowMaterialBlind, EnergyWindowMaterialShade
 from .programtype import ProgramTypeAbridged, ProgramType
 from .load import PeopleAbridged, LightingAbridged, ElectricEquipmentAbridged, \
     GasEquipmentAbridged, ServiceHotWaterAbridged, InfiltrationAbridged, \
@@ -29,6 +30,7 @@ from .hvac.doas import FCUwithDOASAbridged, WSHPwithDOASAbridged, VRFwithDOASAbr
     RadiantwithDOASAbridged
 from .hvac.heatcool import FCU, WSHP, VRF, Baseboard, EvaporativeCooler, Residential, \
     WindowAC, GasUnitHeater, Radiant
+from .hvac.detailed import DetailedHVAC
 from .shw import SHWSystem
 
 
@@ -273,7 +275,7 @@ class ModelEnergyProperties(NoExtraBaseModel):
             EnergyMaterial, EnergyMaterialNoMass, EnergyMaterialVegetation,
             EnergyWindowMaterialGlazing, EnergyWindowMaterialSimpleGlazSys,
             EnergyWindowMaterialGas, EnergyWindowMaterialGasMixture,
-            EnergyWindowMaterialGasCustom,
+            EnergyWindowMaterialGasCustom, EnergyWindowFrame,
             EnergyWindowMaterialBlind, EnergyWindowMaterialShade
         ]
     ] = Field(
@@ -288,7 +290,8 @@ class ModelEnergyProperties(NoExtraBaseModel):
             FCUwithDOASAbridged, WSHPwithDOASAbridged, VRFwithDOASAbridged,
             RadiantwithDOASAbridged,
             FCU, WSHP, VRF, Baseboard, EvaporativeCooler, Residential,
-            WindowAC, GasUnitHeater, Radiant
+            WindowAC, GasUnitHeater, Radiant,
+            DetailedHVAC
         ]
     ] = Field(
         default=None,
