@@ -4,7 +4,7 @@ from typing import List, Union
 from enum import Enum
 
 from ._base import IDdBaseModel
-from .boundarycondition import Outdoors, Surface, Ground, Adiabatic
+from .boundarycondition import Outdoors, Surface, Ground, Adiabatic, OtherSideTemperature
 
 from .energy.properties import ShadeEnergyPropertiesAbridged, \
     DoorEnergyPropertiesAbridged, ApertureEnergyPropertiesAbridged, \
@@ -198,7 +198,7 @@ class Face(IDdBaseModel):
 
     face_type: FaceType
 
-    boundary_condition: Union[Ground, Outdoors, Adiabatic, Surface]
+    boundary_condition: Union[Ground, Outdoors, Adiabatic, Surface, OtherSideTemperature]
 
     @validator('boundary_condition')
     def surface_bc_objects(cls, v):
@@ -287,7 +287,7 @@ class Room(IDdBaseModel):
         description='An integer noting how many times this Room is repeated. '
         'Multipliers are used to speed up the calculation when similar Rooms are '
         'repeated more than once. Essentially, a given simulation with the '
-        'Room is run once and then the result is mutliplied by the multiplier.'
+        'Room is run once and then the result is multiplied by the multiplier.'
     )
 
     exclude_floor_area: bool = Field(
